@@ -127,15 +127,19 @@ encoding, etc."
 
 (define* (rotate-and-reopen-log-file output file rotated-file
                                      #:optional (mode #o640))
-  "Rotate @var{file}, currently opened as port @var{output}, to
+  "Rotate @var{file}, currently or previously opened as port @var{output}, to
 @var{rotated-file}; close @var{output} and reopen @var{file} with @var{mode}
 and return the resulting output port.  If rotation or reopening fails, return
 @code{#f}."
   (local-output (l10n "Rotating '~a' to '~a'.")
                 file rotated-file)
-  (newline output)
-  (log-line (l10n "Rotating log.") output)
-  (close-port output)
+
+  (let ((output (if (port-closed? output)
+                    (open-log-file file mode)
+                    output)))
+    (newline output)
+    (log-line (l10n "Rotating log.") output)
+    (close-port output))
 
   (let ((output (catch 'system-error
                   (lambda ()
