@@ -1,5 +1,5 @@
 # GNU Shepherd --- Check the 'daemonize' action of the root service.
-# Copyright © 2023 Ludovic Courtès <ludo@gnu.org>
+# Copyright © 2023-2024 Ludovic Courtès <ludo@gnu.org>
 #
 # This file is part of the GNU Shepherd.
 #
@@ -37,7 +37,7 @@ pid="t-pid-$$"
 
 herd="herd -s $socket"
 
-trap "rm -f $socket $conf $log;
+trap "cat $log || true; rm -f $socket $conf $log;
       test -f $pid && kill \`cat $pid\` || true; rm -f $pid" EXIT
 
 cat > "$conf" <<EOF
@@ -59,6 +59,14 @@ shepherd -I -s "$socket" -c "$conf" --pid="$pid" --log="$log"
 
 until test -f "$pid"; do sleep 0.5; done
 
+# Wait until it has daemonized.
+until grep "Now running as process [0-9]" "$log"; do sleep 0.2; done
+
+# This command should display shepherd's own PID, post-daemonize.
+new_pid="$($herd eval root '(getpid)' | tail -1)"
+kill -0 "$new_pid"
+$herd status root | grep "PID: $new_pid"
+
 $herd status
 until $herd status a | grep running; do sleep 0.3; done
 
